@@ -23,6 +23,7 @@ DIRS = { # maps a directory name to its easel module name
         "pages": "page",
         "quiz_questions": "quiz_question",
         "quizzes": "quiz",
+        "local": "",
         }
 
 def isurl(url):
@@ -75,6 +76,10 @@ def write_config(hostname, token, dry_run):
     return True
 
 def load_db():
+    # TODO: since this just silently creates a db if it doesn't exist, it's
+    # easy to pollute the directories with tons of empty dbs. if it doesn't
+    # exist, we probably don't want to run the command anyway so should we just
+    # log and error and abort?
     return tinydb.TinyDB(".easeldb", sort_keys=True, indent=4, separators=(',', ': '))
 
 def setup_directories(dry_run):
@@ -158,7 +163,10 @@ def do_request(path, params, method, upload=None, dry_run=False):
                     logging.debug(json.dumps(results, sort_keys=True, indent=4))
                     if 'errors' in results:
                         for err in results['errors']:
-                            logging.error("Canvas Error: " + err.get('message'))
+                            if isinstance(err, dict):
+                                logging.error("Canvas Error: " + err.get('message'))
+                            else:
+                                logging.error("Canvas Error: " + str(err))
                 else:
                     # the last page
                     r = resp.json()
